pub struct OpenDirectoryRequest { /* private fields */ }Available on crate feature
open_uri only.Expand description
A builder-pattern type to open a directory.
Implementations
Sourceimpl OpenDirectoryRequest
impl OpenDirectoryRequest
Sourcepub fn identifier(self, identifier: impl Into<Option<WindowIdentifier>>) -> Self
pub fn identifier(self, identifier: impl Into<Option<WindowIdentifier>>) -> Self
Sets a window identifier.
Sourcepub fn activation_token(
self,
activation_token: impl Into<Option<ActivationToken>>,
) -> Self
pub fn activation_token( self, activation_token: impl Into<Option<ActivationToken>>, ) -> Self
Sets the token that can be used to activate the chosen application.
Sourcepub fn connection(self, connection: Option<Connection>) -> Self
pub fn connection(self, connection: Option<Connection>) -> Self
Sets a connection to use other than the internal one.